==> plugin%20Wao%20v2.4.8.zip: plugin Wao/paypals/paypal-entry-point.php <==
<?php
/*
 * ENTRADA DEL PLUGIN PAYPAL
*/

defined( 'ABSPATH' ) || exit; 
 
$GLOBALS['pp_soy_servidor']=soy_servidor();
$GLOBALS['pp_soy_cliente']=soy_cliente();
$GLOBALS['pp_server_id']=get_main_shop(); //obtener con get_option('pp_server_id'); aplicado en el site_id=1

if($GLOBALS['pp_soy_servidor']){
	include('paypal-cpt-single.php');
	include('paypal-server-config.php');
}//fin de si pp_soy_servidor

if($GLOBALS['pp_soy_cliente']){
	include('paypal-return-paypals-table.php');	// **esto inicialmente en servidor **
	include('paypal-return-client-process.php');//paypal_status_update(), paypal_status_update_multiselect(), paypal_update_sales()
	include('paypal-client-config.php');//1C Crear page, 2C Register Settings, 3C Los inputs 
	include('paypal-client-functions.php'); //crea usuario, template, page, scripts, abre popup
	include('paypal-client-widgets.php'); //Funciones para crear los widgets de red y pais
	include('paypal-client-process.php'); //Solo la funcion actualizaventapaypal()
}

/* 
  _    _             _                                                    
 | |  | |           | |                                                   
 | |__| | ___   ___ | | _____    ___ ___  _ __ ___  _   _ _ __   ___  ___ 
 |  __  |/ _ \ / _ \| |/ / __|  / __/ _ \| '_ ` _ \| | | | '_ \ / _ \/ __|
 | |  | | (_) | (_) |   <\__ \ | (_| (_) | | | | | | |_| | | | |  __/\__ \
 |_|  |_|\___/ \___/|_|\_\___/  \___\___/|_| |_| |_|\__,_|_| |_|\___||___/
                                                                          
                                                                          
*/
//Estilo para paginas de configuracion
function admin_style0() 
{
	echo "<style>.config {padding:20px;margin:5px;background-color:GhostWhite;border:solid 1px blac;border-radius:15px;box-shadow: 2px 2px 2px 1px rgba(0, 0, 0, 0.2);}</style>";
}
add_action('admin_enqueue_scripts', 'admin_style0');
//Estilo para ancho de columna en tabla cpt paypals
function admin_style1() 
{
echo "<style>.column-username {width:300px;} .column-primary {width:300px;}</style>";
}
add_action('admin_enqueue_scripts', 'admin_style1');
/*

___________                  .__                             
\_   _____/_ __  ____   ____ |__| ____   ____   ____   ______
 |    __)|  |  \/    \_/ ___\|  |/  _ \ /    \_/ __ \ /  ___/
 |     \ |  |  /   |  \  \___|  (  <_> )   |  \  ___/ \___ \ 
 \___  / |____/|___|  /\___  >__|\____/|___|  /\___  >____  >
     \/             \/     \/               \/     \/     \/ 

*/

function soy_servidor(){
	if(is_multisite()){
		$server_id=get_blog_option(1,'_pp_server_id');
		return $server_id==get_current_blog_id()?true:false;
	}else{
		return true;
	}
	//return get_paypal_option('pp_servidor')=="S"?true:false;
}
function soy_cliente(){
	//return get_paypal_option('pp_cliente')=="S"?true:false;
	return true;
}
function get_paypal_option($fila){
	//pp_servidor:"N"|urlmanuals:url|multiple_countries:"S"|checkout:"S"|payments:"N"|periodsales:"A"
	$ppoption=get_option('_paypal_options');
	return $ppoption[$fila];
}
function get_paypal_options(){
	return get_option("_paypal_options");
} 
function initial_config(){ // Llamado desde paypal-server-config o payapal-client-config
	$initdata=array('urlmanuals'=>'','multiple_countries'=>'S','checkout'=>'S','payments'=>'N','periodsales'=>'A','pp_method'=>'C','diasborrar'=>100);
	if(is_multisite()){
		$pp_server_id = get_blog_option(1,'_pp_server_id');
		if(is_bool($pp_server_id)||$pp_server_id==""){
			update_blog_option(1,'_pp_server_id','1');
		}
		$paypal_options = get_blog_option($pp_server_id,'_paypal_options');
		if(is_bool($paypal_options)||$paypal_options==""){
			update_blog_option(1,'_paypal_options',$initdata);
		}
	}else{
		$pp_server_id = get_option('_pp_server_id');
		if(is_bool($pp_server_id)||$pp_server_id==""){
			update_option('_pp_server_id','1');
		$paypal_options = get_option('_paypal_options');
		if(is_bool($paypal_options)||$paypal_options==""){
			update_option('_paypal_options',$initdata);
		}
		}
	}
}
function paypal_color_span($_ppcategory){
	switch ($_ppcategory){
		case 'r':
			$color='Pink';
			$bcolor='Crimson';
			break;
		case 'g':
			$color='#E9F5F0';
			$bcolor='YellowGreen';
			break;
		case 'y':
			$color='LemonChiffon'; 
			$bcolor='#FFA500	';
			break;
		default:
			$color='white';
			$bcolor='gray';
	}
	//return "<span style='background-color:".$color.";border-radius:5px;widht:15px;'>&nbsp;&nbsp;&nbsp;</span>";
	return "<span style='background-color:".$color.";border:solid 1px ".$bcolor."; border-radius:15px;'>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>&nbsp;&nbsp;";
}
function get_main_shop(){ //actualizado, saca _pp_server_id de wp_options
	$q="SELECT option_value FROM wp_options WHERE option_name = '_pp_server_id'";
	return $GLOBALS['wpdb']->get_var($q);
}
function get_paypal_server_option($param){
	if(is_multisite()){
		$main=get_main_shop();
		$ppopt=get_blog_option($main, "_paypal_options");
		return $ppopt[$param];
	}else{
		$ppopt=get_option("_paypal_options");
		return $ppopt[$param];
	}
}
//se utiliza para el cliente
function get_paypal_payment_method(){
	$options = get_option( 'woocommerce_paypal_settings' );
	if(is_bool($options)){
		$options['enabled']='no';
	}
	if($options['enabled']=="yes"){
		$def="Woocommerce";
	}else{
		$options1 = get_option( 'woocommerce_ppec_paypal_settings' );
		if(is_bool($options1)){
			$options1['enabled']='no';
		}
		if($options1['enabled']=="yes"){
			$def="checkout";
		}else{
			$options2 = get_option( 'woocommerce-ppcp-settings' ); 
			if(is_bool($options2)){
				$options2['enabled']=FALSE;
			}
			if ($options2['enabled']==TRUE){
				$def="payments"; 
			}else{
				$def="nomethod"; 
			}//fin de woocommerce-ppcp-settings
		}
	}// fin de else
	return $def;
}// function get_paypal_payment_method() end


function paypal_change_history_page(){
	echo '<div class="config">';
	echo "<h2><div style='text-align:center;background-color:#e6f2ff;padding:30px;border:solid 1px white;'>Historial de cambios</div></h2>";
	echo "<br>";
	echo oldpaypals();
	echo '</div>';
	
}
/// FUNCIONES COMUNES PARA INSERTAR EL SUBMENU Historial de cambios BAJO EL MENU PAYPALS
/// SON INVOCADAS DESDE paypal_server_config.php y paypal_client_config.php RESPECTIVAMENTE

function oldpaypals(){
	$estilo = "<style>
		.par{background-color:WhiteSmoke}
		.impar{background-color:#fefefe}
		.cabeza{background-color:Gainsboro}
		.uno{width:120px;border-left:solid 1px Gainsboro;}
		.dos{width:220px;border-left:solid 1px Gainsboro;}
		.none{}
		.grande{font-size:17px;}
		.centro{margin:auto;border: solid 1px Gainsboro }
		</style>";
	$oldpayp = get_option( '_oldpaypals' );
	if(is_bool($oldpayp)){
		return "nothing here.";
	}
	$oldpayp = solo100cambios($oldpayp);
	//update_option('_oldpaypals',$oldpayp);
	$oldpayprows=explode("|",$oldpayp);
	$td = td("NUM","unox");
	$td .= td("PAYPAL","unox");
	$td .= td("CHANGE DATE (Outgoing)","unox");
	$trs = tr($td,"cabeza");
	$par="par";
	$num=1;
	foreach ($oldpayprows as $oldpayprow){
		$oldpaypfields=explode("*",$oldpayprow);
		$td="";
		$uno="uno";
		if($oldpaypfields[0]<>"Sales Revenue to zero"){
			$td = td($num++);
			$td.= td($oldpaypfields[0],"uno");
			$td.= td($oldpaypfields[1],"dos");
			$trs .= tr($td,$par);
			$par=$par=="par"?"impar":"par";
		}
	}
	$retorno=tabla($trs,"centro grande");
	$retorno=tag($retorno,"div");
	$retorno=$estilo.$retorno;
	return $retorno;
}

function solo100cambios($oldpaypal){
	$len= strlen($oldpaypal);
	$len=$len-1;
	$ult=substr($oldpaypal,$len,1);
	if($ult=="|"){
		$len=$len-1;
		$oldpaypal=substr($oldpaypal,1,$len);
	}
	$oldpaypalsarray=explode("|",$oldpaypal);
	$reverso=array_reverse($oldpaypalsarray);
	$cien=1;
	$retorno=array();
	$guarda=array();
	foreach($reverso as $fila){
		$fields=explode("*",$fila);
		if ($fields[0]<>"Sales Revenue to zero" && $cien<=100){
			$retorno[]=$fila;
			$cien++;
		}
		if($cien<=101){
			$guarda[] = $fila;
		}
	}
	$guardareverse=array_reverse($guarda);
	update_option('_oldpaypals',implode("|",$guardareverse));
	$newarray=array_reverse($retorno);
	return implode("|",$newarray);
}

==> plugin%20Wao%20v2.5.31.zip: plugin Wao/paypals/paypal-entry-point.php <==
<?php
/*
 * ENTRADA DEL PLUGIN PAYPAL
*/

defined( 'ABSPATH' ) || exit; 
 
$GLOBALS['pp_soy_servidor']=soy_servidor();
$GLOBALS['pp_soy_cliente']=soy_cliente();
$GLOBALS['pp_server_id']=get_main_shop(); //obtener con get_option('pp_server_id'); aplicado en el site_id=1

if($GLOBALS['pp_soy_servidor']){
	include('paypal-cpt-single.php');
	include('paypal-server-config.php');
}//fin de si pp_soy_servidor

if($GLOBALS['pp_soy_cliente']){
	include('paypal-return-paypals-table.php');	// **esto inicialmente en servidor **
	include('paypal-return-client-process.php');//paypal_status_update(), paypal_status_update_multiselect(), paypal_update_sales()
	include('paypal-client-config.php');//1C Crear page, 2C Register Settings, 3C Los inputs 
	include('paypal-client-functions.php'); //crea usuario, template, page, scripts, abre popup
	include('paypal-client-widgets.php'); //Funciones para crear los widgets de red y pais
	include('paypal-client-process.php'); //Solo la funcion actualizaventapaypal()
}

/* 
  _    _             _                                                    
 | |  | |           | |                                                   
 | |__| | ___   ___ | | _____    ___ ___  _ __ ___  _   _ _ __   ___  ___ 
 |  __  |/ _ \ / _ \| |/ / __|  / __/ _ \| '_ ` _ \| | | | '_ \ / _ \/ __|
 | |  | | (_) | (_) |   <\__ \ | (_| (_) | | | | | | |_| | | | |  __/\__ \
 |_|  |_|\___/ \___/|_|\_\___/  \___\___/|_| |_| |_|\__,_|_| |_|\___||___/
                                                                          
                                                                          
*/
//Estilo para paginas de configuracion
function admin_style0() 
{
	echo "<style>.config {padding:20px;margin:5px;background-color:GhostWhite;border:solid 1px blac;border-radius:15px;box-shadow: 2px 2px 2px 1px rgba(0, 0, 0, 0.2);}</style>";
}
add_action('admin_enqueue_scripts', 'admin_style0');
//Estilo para ancho de columna en tabla cpt paypals
function admin_style1() 
{
echo "<style>.column-username {width:300px;} .column-primary {width:300px;}</style>";
}
add_action('admin_enqueue_scripts', 'admin_style1');
/*

___________                  .__                             
\_   _____/_ __  ____   ____ |__| ____   ____   ____   ______
 |    __)|  |  \/    \_/ ___\|  |/  _ \ /    \_/ __ \ /  ___/
 |     \ |  |  /   |  \  \___|  (  <_> )   |  \  ___/ \___ \ 
 \___  / |____/|___|  /\___  >__|\____/|___|  /\___  >____  >
     \/             \/     \/               \/     \/     \/ 

*/

function soy_servidor(){
	if(is_multisite()){
		$server_id=get_blog_option(1,'_pp_server_id');
		return $server_id==get_current_blog_id()?true:false;
	}else{
		return true;
	}
	//return get_paypal_option('pp_servidor')=="S"?true:false;
}
function soy_cliente(){
	//return get_paypal_option('pp_cliente')=="S"?true:false;
	return true;
}
function get_paypal_option($fila){
	//pp_servidor:"N"|urlmanuals:url|multiple_countries:"S"|checkout:"S"|payments:"N"|periodsales:"A"
	$ppoption=get_option('_paypal_options');
	return $ppoption[$fila];
}
function get_paypal_options(){
	return get_option("_paypal_options");
} 
function initial_config(){ // Llamado desde paypal-server-config o payapal-client-config
	$initdata=array('urlmanuals'=>'','multiple_countries'=>'S','checkout'=>'S','payments'=>'N','periodsales'=>'A','pp_method'=>'C','diasborrar'=>100);
	if(is_multisite()){
		$pp_server_id = get_blog_option(1,'_pp_server_id');
		if(is_bool($pp_server_id)||$pp_server_id==""){
			update_blog_option(1,'_pp_server_id','1');
		}
		$paypal_options = get_blog_option($pp_server_id,'_paypal_options');
		if(is_bool($paypal_options)||$paypal_options==""){
			update_blog_option(1,'_paypal_options',$initdata);
		}
	}else{
		$pp_server_id = get_option('_pp_server_id');
		if(is_bool($pp_server_id)||$pp_server_id==""){
			update_option('_pp_server_id','1');
		$paypal_options = get_option('_paypal_options');
		if(is_bool($paypal_options)||$paypal_options==""){
			update_option('_paypal_options',$initdata);
		}
		}
	}
}
function paypal_color_span($_ppcategory){
	$contenido = '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
	switch ($_ppcategory){
		case 'r':
			$bcolor='Pink';
			$color='Crimson';
			$style="background-color:".$bcolor.";border:solid 1px ".$color."; border-radius:15px;";
			break;
		case 'g':
			$bcolor='#E9F5F0';
			$color='YellowGreen';
			$style="background-color:".$bcolor.";border:solid 1px ".$color."; border-radius:15px;";
			break;
		case 'y':
			$bcolor='LemonChiffon'; 
			$color='#FFA500';
			$style="background-color:".$bcolor.";border:solid 1px ".$color."; border-radius:15px;";
			break;
		case 'x':
			$bcolor='white'; 
			$color='red';
			$style="background-color:".$bcolor.";border:solid 1px ".$color."; border-radius:15px;color:".$color.";font-size:24px;";
			$contenido = '&nbsp;&#x2716;&nbsp;';
			break;
		case '-':
			$bcolor='red'; 
			$color='white';
			$style="background-color:".$bcolor.";border:solid 1px ".$color."; border-radius:15px;color:".$color.";font-size:24px;";
			$contenido = '&nbsp;&ndash;&nbsp;';
			break;
		default:
			$bcolor='white';
			$color='gray';
			$style="background-color:".$bcolor.";border:solid 1px ".$color."; border-radius:15px;";
	}
	//return "<span style='background-color:".$color.";border-radius:5px;widht:15px;'>&nbsp;&nbsp;&nbsp;</span>";
	$retorno = "<span style='".$style."'>".$contenido."</span>&nbsp;&nbsp;";
	return $retorno;
}
function get_main_shop(){ //actualizado, saca _pp_server_id de wp_options
	$q="SELECT option_value FROM wp_options WHERE option_name = '_pp_server_id'";
	return $GLOBALS['wpdb']->get_var($q);
}
function get_paypal_server_option($param){
	if(is_multisite()){
		$main=get_main_shop();
		$ppopt=get_blog_option($main, "_paypal_options");
		return $ppopt[$param];
	}else{
		$ppopt=get_option("_paypal_options");
		return $ppopt[$param];
	}
}
//se utiliza para el cliente
function get_paypal_payment_method(){
	$options = get_option( 'woocommerce_paypal_settings' );
	if(is_bool($options)){
		$options['enabled']='no';
	}
	if($options['enabled']=="yes"){
		$def="Woocommerce";
	}else{
		$options1 = get_option( 'woocommerce_ppec_paypal_settings' );
		if(is_bool($options1)){
			$options1['enabled']='no';
		}
		if($options1['enabled']=="yes"){
			$def="checkout";
		}else{
			$options2 = get_option( 'woocommerce-ppcp-settings' ); 
			if(is_bool($options2)){
				$options2['enabled']=FALSE;
			}
			if ($options2['enabled']==TRUE){
				$def="payments"; 
			}else{
				$def="nomethod"; 
			}//fin de woocommerce-ppcp-settings
		}
	}// fin de else
	return $def;
}// function get_paypal_payment_method() end


function paypal_change_history_page(){
	echo '<div class="config">';
	echo "<h2><div style='text-align:center;background-color:#e6f2ff;padding:30px;border:solid 1px white;'>Historial de cambios</div></h2>";
	echo "<br>";
	echo oldpaypals();
	echo '</div>';
	
}
/// FUNCIONES COMUNES PARA INSERTAR EL SUBMENU Historial de cambios BAJO EL MENU PAYPALS
/// SON INVOCADAS DESDE paypal_server_config.php y paypal_client_config.php RESPECTIVAMENTE

function oldpaypals(){
	$estilo = "<style>
		.par{background-color:WhiteSmoke}
		.impar{background-color:#fefefe}
		.cabeza{background-color:Gainsboro}
		.uno{width:120px;border-left:solid 1px Gainsboro;}
		.dos{width:220px;border-left:solid 1px Gainsboro;}
		.none{}
		.grande{font-size:17px;}
		.centro{margin:auto;border: solid 1px Gainsboro }
		</style>";
	$oldpayp = get_option( '_oldpaypals' );
	if(is_bool($oldpayp)){
		return "nothing here.";
	}
	$oldpayp = solo100cambios($oldpayp);
	//update_option('_oldpaypals',$oldpayp);
	$oldpayprows=explode("|",$oldpayp);
	$td = td("NUM","unox");
	$td .= td("PAYPAL","unox");
	$td .= td("CHANGE DATE (Outgoing)","unox");
	$trs = tr($td,"cabeza");
	$par="par";
	$num=1;
	foreach ($oldpayprows as $oldpayprow){
		$oldpaypfields=explode("*",$oldpayprow);
		$td="";
		$uno="uno";
		if($oldpaypfields[0]<>"Sales Revenue to zero"){
			$td = td($num++);
			$td.= td($oldpaypfields[0],"uno");
			$td.= td($oldpaypfields[1],"dos");
			$trs .= tr($td,$par);
			$par=$par=="par"?"impar":"par";
		}
	}
	$retorno=tabla($trs,"centro grande");
	$retorno=tag($retorno,"div");
	$retorno=$estilo.$retorno;
	return $retorno;
}

function solo100cambios($oldpaypal){
	$len= strlen($oldpaypal);
	$len=$len-1;
	$ult=substr($oldpaypal,$len,1);
	if($ult=="|"){
		$len=$len-1;
		$oldpaypal=substr($oldpaypal,1,$len);
	}
	$oldpaypalsarray=explode("|",$oldpaypal);
	$reverso=array_reverse($oldpaypalsarray);
	$cien=1;
	$retorno=array();
	$guarda=array();
	foreach($reverso as $fila){
		$fields=explode("*",$fila);
		if ($fields[0]<>"Sales Revenue to zero" && $cien<=100){
			$retorno[]=$fila;
			$cien++;
		}
		if($cien<=101){
			$guarda[] = $fila;
		}
	}
	$guardareverse=array_reverse($guarda);
	update_option('_oldpaypals',implode("|",$guardareverse));
	$newarray=array_reverse($retorno);
	return implode("|",$newarray);
}
